Documentation
¶
Index ¶
Constants ¶
const ( WaitUntilPrimaryRolled = "primary-rolled" WaitUntilDrainingStarted = "draining-started" )
const TaskRoleKnockoutValue = "None"
TaskRoleKnockoutValue when passed value matches the task role is set to nil
Variables ¶
var ( // ErrNothingToRollback nothing to rollback ErrNothingToRollback = errors.New("nothing to rollback") // ErrPermanentNothingToRollback permanent nothing to rollback ErrPermanentNothingToRollback = backoff.Permanent(ErrNothingToRollback) // ErrSuccessfulRollback successful rollback ErrSuccessfulRollback = errors.New("successful rollback") // ErrFailedRollback failed rollback ErrFailedRollback = errors.New("failed rollback") )
var ( // EnvKnockOutValue value used to knock off environment variables EnvKnockOutValue = "" // ErrDeploymentChangedElsewhere the deployment was changed elsewhere ErrDeploymentChangedElsewhere = errors.New("the deployment was changed elsewhere") // ErrOtherThanPrimaryDeploymentFound service update didn't complete ErrOtherThanPrimaryDeploymentFound = errors.New("other than PRIMARY deployment found") // ErrNotRunningDesiredCount service update completed but number of containers not matching desired count ErrNotRunningDesiredCount = errors.New("not running the desired count") // ErrServiceNotFound trying to update a service that doesn't exist ErrServiceNotFound = errors.New("the service does not exist") // ErrWaitingForDrainingState the service doesn't have any target which transitioned to draining state ErrWaitingForDrainingState = errors.New("waiting for draining state") // ErrInvalidWaitUntil received an invalid wait until ErrInvalidWaitUntil = errors.New("invalid wait until received") // ErrServiceDeletedAfterUpdate service was updated and then deleted elsewhere ErrServiceDeletedAfterUpdate = backoff.Permanent(errors.New("the service was deleted after the update")) // ErrContainerInstanceNotFound the container instance was removed from the cluster elsewhere ErrContainerInstanceNotFound = backoff.Permanent(errors.New("container instance not found")) // ErrLoadBalancerNotConfigured the service doesn't have a load balancer configured ErrLoadBalancerNotConfigured = backoff.Permanent(errors.New("the service was deleted after the update")) )
var WaitUntilOptionList = []string{WaitUntilPrimaryRolled, WaitUntilDrainingStarted}
Functions ¶
This section is empty.
Types ¶
type ECSServiceUpdate ¶
type ECSServiceUpdate struct {
EcsApi ecsiface.ECSAPI // ECS Api
ElbApi elbv2iface.ELBV2API // ELBV2 Api
Cluster string // Cluster which the service is deployed to
Service string // Name of the service
Image map[string]string // Map of container names and images
Environment map[string]map[string]string // Map of container names environment variable name and value
Secrets map[string]map[string]string // Map of container names environment variable name and valueFrom
LogDriverOptions map[string]map[string]map[string]string // Map of container names log driver name log driver option and value
LogDriverSecrets map[string]map[string]map[string]string // Map of container names log driver name log driver secret and valueFrom
TaskRole string // Task IAM Role if TaskRoleKnockoutValue used, it is cleared
DesiredCount *int64 // If nil the service desired count is not altered
BackOff backoff.BackOff // BackOff strategy to use when validating the update
Taskdef string // If non empty used as base task definition instead of the current task definition
WaitUntil *string // Decide wether to wait until the service "started-draining" (only valid for services with Load Balancers attached) or until the deployment "primary-rolled" (default)
}
ECSServiceUpdate encapsulates the attributes of an ECS service update
func (*ECSServiceUpdate) Apply ¶
func (e *ECSServiceUpdate) Apply() error
Apply the ECS Service Update
type EnforceLaunchConfig ¶
type EnforceLaunchConfig struct {
ECSAPI ecs.ECS
ASAPI autoscaling.AutoScaling
EC2API ec2.EC2
ASGName string
ECSClusterName string
BackOff backoff.BackOff
}
EnforceLaunchConfig encapsulates the attributes of a LaunchConfig enforcement
func (*EnforceLaunchConfig) Apply ¶
func (e *EnforceLaunchConfig) Apply() error
Apply the LaunchConfig enforcement
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
enforce-aws-ecs-asg-launchconfig
command
|
|
|
update-aws-ecs-service
command
|
Click to show internal directories.
Click to hide internal directories.